pytest-9.1.0
=======================================

The pytest team is proud to announce the 9.1.0 release!

This release contains new features, improvements, and bug fixes,
the full list of changes is available in the changelog:

    https://docs.pytest.org/en/stable/changelog.html

For complete documentation, please visit:

    https://docs.pytest.org/en/stable/

As usual, you can upgrade from PyPI via:

    pip install -U pytest

Thanks to all of the contributors to this release:

* 1Utkarsh1
* Aditya Giri
* Alejandro Villate
* Alex Waygood
* Anton Zhilin
* Antonis Gardi
* Bruno Oliveira
* Bubble-Interface
* Charles-Meldhine Madi Mnemoi
* DavidAG
* Denis Cherednichenko
* DetachHead
* Dhruva Kumar
* Dr Alex Mitre
* EternalRights
* Fazeel Usmani
* Florian Bruhin
* Freya Bruhin
* Fridayworks
* Garion Milazzo
* Hamza Mobeen
* Hugo van Kemenade
* Ilya Manafi
* John Litborn
* Julia Knaak
* Junhao Liao
* Kadir Can Ozden
* Lai Jia Yang
* Liam DeVoe
* Lily Wu
* Marco Edward Gorelli
* Maxime Grenu
* Mike Fiedler
* Mikhail Golikov
* Mukunda Rao Katta
* NIYONSHUTI Emmanuel
* Nikesh Chavhan
* Noa Levi
* Paul Zuradzki
* Philipp A.
* Pierre Sassoulas
* Praneeth Kodumagulla
* Puneet Dixit
* Ran Benita
* Randy Döring
* Ronald Eddy Jr
* Ronny Pfannschmidt
* Samuel Newbold
* Stanis Trendelenburg
* Sviatoslav Sydorenko
* Sylvain MARIE
* Syncrain
* Sóla Lusøt
* Tejas Verma
* Tobias Deiminger
* Tom Most
* V1SHAL421
* Varun Chawla
* Vladimir
* Warren
* Will Toohey
* Yast
* Yusuke Kadowaki
* arya rizky
* dariomesic
* isra17
* jakkdl
* jiayang lai
* jxramos
* minbang930
* morning-verlu
* ron
* 사재혁
* 🇺🇦 Sviatoslav Sydorenko (Святослав Сидоренко)


Happy testing,
The pytest Development Team
